@@ -61,7 +61,7 @@ CONFIG_FILE = '~/.bbrf/config.json'
 REGEX_DOMAIN = re.compile('^(?:[a-z0-9_](?:[a-z0-9-_]{0,61}[a-z0-9])?\\.)+[a-z0-9][a-z0-9-]{0,61}[a-z0-9]$')
 # regex to match IP addresses and CIDR ranges - thanks https://www.regextester.com/93987
 REGEX_IP = re.compile('^([0-9]{1,3}\\.){3}[0-9]{1,3}(/([0-9]|[1-2][0-9]|3[0-2]))?$')
-VERSION = '1.1.8'
+VERSION = '1.1.9'
 
 class BBRFClient:
     config = {}
@@ -804,7 +804,7 @@ class BBRFClient:
     
     def list_documents_view(self, doctype, view, list_all = False):
         if list_all:
-            return self.api.get_documents_view(None, doctype, view)
+            return self.api.get_documents_view(None, doctype, view, show_disabled=self.arguments['--show-disabled'])
         return self.api.get_documents_view(self.get_program(), doctype, view)
     
     def get_blacklist(self, copy=None):
